==> fcl_0.3.0.orig.tar.gz: fcl-0.3.0/src/ccd/interpolation/interpolation_linear.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2011, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Willow Garage, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

/** \author Dalibor Matura, Jia Pan */

#include "fcl/ccd/interpolation/interpolation_linear.h"
#include "fcl/ccd/interpolation/interpolation_factory.h"

namespace fcl 
{

InterpolationType interpolation_linear_type = LINEAR;

InterpolationLinear::InterpolationLinear() : Interpolation(0.0, 1.0)
{}

InterpolationLinear::InterpolationLinear(FCL_REAL start_value, FCL_REAL end_value) : Interpolation(start_value, end_value)
{}

FCL_REAL InterpolationLinear::getValue(FCL_REAL time) const
{
  return value_0_ + (value_1_ - value_0_) * time;
}

FCL_REAL InterpolationLinear::getValueLowerBound() const
{
  return value_0_;
}

FCL_REAL InterpolationLinear::getValueUpperBound() const
{
  return value_1_;
}

InterpolationType InterpolationLinear::getType() const
{
  return interpolation_linear_type;
}

boost::shared_ptr<Interpolation> InterpolationLinear::create(FCL_REAL start_value, FCL_REAL end_value)
{
  return boost::shared_ptr<Interpolation>(new InterpolationLinear(start_value, end_value) );
}

void InterpolationLinear::registerToFactory()
{
  InterpolationFactory::instance().registerClass(interpolation_linear_type, create);
}

FCL_REAL InterpolationLinear::getMovementLengthBound(FCL_REAL time) const
{
  return getValueUpperBound() - getValue(time);
}

FCL_REAL InterpolationLinear::getVelocityBound(FCL_REAL time) const
{
  return (value_1_ - value_0_);
}

}

==> fcl_0.5.0.orig.tar.gz: fcl-0.5.0/src/ccd/interpolation/interpolation_linear.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2011-2014, Willow Garage, Inc.
 *  Copyright (c) 2014-2016, Open Source Robotics Foundation
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Open Source Robotics Foundation nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

/** \author Dalibor Matura, Jia Pan */

#include "fcl/ccd/interpolation/interpolation_linear.h"
#include "fcl/ccd/interpolation/interpolation_factory.h"

namespace fcl 
{

InterpolationType interpolation_linear_type = LINEAR;

InterpolationLinear::InterpolationLinear() : Interpolation(0.0, 1.0)
{}

InterpolationLinear::InterpolationLinear(FCL_REAL start_value, FCL_REAL end_value) : Interpolation(start_value, end_value)
{}

FCL_REAL InterpolationLinear::getValue(FCL_REAL time) const
{
  return value_0_ + (value_1_ - value_0_) * time;
}

FCL_REAL InterpolationLinear::getValueLowerBound() const
{
  return value_0_;
}

FCL_REAL InterpolationLinear::getValueUpperBound() const
{
  return value_1_;
}

InterpolationType InterpolationLinear::getType() const
{
  return interpolation_linear_type;
}

std::shared_ptr<Interpolation> InterpolationLinear::create(FCL_REAL start_value, FCL_REAL end_value)
{
  return std::shared_ptr<Interpolation>(new InterpolationLinear(start_value, end_value) );
}

void InterpolationLinear::registerToFactory()
{
  InterpolationFactory::instance().registerClass(interpolation_linear_type, create);
}

FCL_REAL InterpolationLinear::getMovementLengthBound(FCL_REAL time) const
{
  return getValueUpperBound() - getValue(time);
}

FCL_REAL InterpolationLinear::getVelocityBound(FCL_REAL time) const
{
  return (value_1_ - value_0_);
}

}
